package br.ufpr.inf.rp09.statemachine;

import java.util.ArrayDeque;
import java.util.Deque;

import br.ufpr.inf.rp09.statemachine.enumerations.ModastStateEnum;

/**
 * Implementa a maquina de estados que reflete o estado do banco de dados
 * sob uma rotina de testes de stress.
 * 
 * @author Rodrigo Piassetta / GRR20094994
 *
 */
public class ModastStateMachine {

	final static ModastStateEnum INITIAL_STATE = ModastStateEnum.WARMUP_STATE; //estado inicial
	final static ModastStateEnum FINAL_STATE = ModastStateEnum.THRASHING_STATE; //estado final

	private ModastStateEnum state; //estado atual da maquina
	private Deque<Long> stackTimestampTransitions; //pilha de timestamps das transicoes de estado
	private Deque<ModastStateEnum> stackStateTransitions; //pilha dos estados anteriores a transicoes
	
	public ModastStateMachine() {
		this.stackTimestampTransitions = new ArrayDeque<Long>();
		this.stackStateTransitions = new ArrayDeque<ModastStateEnum>();
	}
	
	/**
	 * Configura a maquina de estados para seu estado inicial
	 */
	public void set2InitialState() {
		setStateTransition(INITIAL_STATE);
	}

	public void setStateTransition(ModastStateEnum state) {
		setStateTransition(state, System.currentTimeMillis());
	}

	public void setStateTransition(ModastStateEnum state, long transitionTimestamp) {
		setState(state);
		pushTransition(state, transitionTimestamp);
	}
	
	private void pushTransition(ModastStateEnum state, long timestamp) {
		this.stackStateTransitions.push(state);
		this.stackTimestampTransitions.push(timestamp);
	}

	public ModastStateEnum getState() {
		return state;
	}

	private void setState(ModastStateEnum state) {
		this.state = state;
	}

	public ModastStateEnum getFinalState() {
		return FINAL_STATE;
	}
}
