package br.ufpr.inf.rp09.testresults;

import java.io.File;
import java.io.FileNotFoundException;
import java.util.ArrayList;
import java.util.List;
import java.util.Scanner;

/**
 * Classe responsavel por monitorar o numero de resultados impressos no arquivo de log
 * das amostras executadas durante o teste, determinando se o teste esta em andamento
 * ou foi finalizado. 
 * 
 * @author Rodrigo Piassetta / GRR20094994
 */
public class MonitorLogResults {

	private String logFilePath; //caminho do arquivo de log de resultados
	private String sampleLabel; //rotulo identificador das amostras 
	private int expectedTotalRequests; //expetativa do total de amostras a serem executadas
	private List<String> sampleRequesteds; //lista com o resultado de cada amostra executada

	public MonitorLogResults() {
		this.sampleLabel = "";
		this.expectedTotalRequests = 0;
		this.sampleRequesteds = new ArrayList<String>();
	}
	
	public void setLogFilePath(String filepath) {
		this.logFilePath = filepath;		
	}
	
	public String getLogFilePath() {
		return this.logFilePath;
	}

	public void setSampleLabel(String label) {
		this.sampleLabel = label;		
	}
	
	public String getSampleLabel() {
		return this.sampleLabel;
	}

	public void setExpectedTotalRequests(int expectedTotalRequests) {
		this.expectedTotalRequests = expectedTotalRequests;
	}

	/**
	 * Verifica se o numero esperado de requisicoes foram registradas
	 * no arquivo de logo de resultados
	 * 
	 * @return true se todas requisicoes foram registradas, senao retorna false
	 */
	public boolean isAllRequestsLogged() {
		boolean allRequestsLogged = false;
		String strNewLine;
		Scanner scannerLog;
		this.sampleRequesteds = new ArrayList<String>();

		try {
			scannerLog = new Scanner(new File(logFilePath));			
	
			while(scannerLog.hasNextLine()) {
				strNewLine = scannerLog.nextLine();
				if(strNewLine.contains(this.sampleLabel))
					this.sampleRequesteds.add(strNewLine);
			}
			
			scannerLog.close();
		} catch (FileNotFoundException e) {
			return allRequestsLogged;
		}
		
		allRequestsLogged = sampleRequesteds.size() >= expectedTotalRequests;
		
		return allRequestsLogged;
	}
	
	public List<String> getSampleRequesteds () {
		return this.sampleRequesteds;
	}
}
