package br.ufpr.inf.rp09.testresults;

import java.util.List;
import java.util.StringTokenizer;

/**
 * Processa e analisa strings de amostras do log de resultados de teste,
 * convertendo e calculando os valores
 * 
 * @author Rodrigo Piassetta / GRR20094994
 *
 */
public class TestResultParser {

	private static final String RESULT_DELIMITER = "|";
	private static final int TIMESTAMP_POSITION = 0;
	private static final int ELAPSED_POSITION = 1;
	private static final int LABEL_POSITION = 2;
	private static final int SUCCESS_POSITION = 3;
	
	private long startTime;
	private long endTime;
	private long totalRequests;
	private long successfulRequests;
	private long errorRequests;

	public TestResultParser() {
		this.startTime = 0L;
		this.endTime = 0L;
		this.totalRequests = 0L;
		this.successfulRequests = 0L;
		this.errorRequests = 0L;
	}

	/**
	 * Processa as strings de amostras de resultados identificadas
	 * por um determinado rotulo e calcula os valores
	 *  
	 * @param sampleRequesteds lista de string das amostras de resultados
	 * @param sampleLabel rotulo identificador da amostra
	 */
	public void processResults(List<String> sampleRequesteds, String sampleLabel) {
		
		for(String strSample : sampleRequesteds) {
			int pos = 0;
			long timestamp = 0L, elapsedTime = 0L;
			String label = "";
			boolean successful = false;
			StringTokenizer tokenStrSample = new StringTokenizer(strSample, RESULT_DELIMITER);
			
			while(tokenStrSample.hasMoreElements()) {
				String element = (String) tokenStrSample.nextElement();
				
				switch(pos) {
					case TIMESTAMP_POSITION:
						timestamp = Long.parseLong(element);
						break;
					case ELAPSED_POSITION:
						elapsedTime = Long.parseLong(element);
						break;
					case LABEL_POSITION:
						label = element;
						break;
					case SUCCESS_POSITION:						
						if(element.compareTo("true") == 0)
							successful = true;
						break;
					default:
						break;
				}
				
				pos++;
			}
			
			//somente tratar valores se o rotulo da amostra for o esperado
			if(label.compareTo(sampleLabel) == 0) {
				if(this.startTime == 0 || timestamp < this.startTime)
					this.startTime = timestamp;
				
				if(timestamp+elapsedTime > this.endTime) {
					this.endTime = timestamp+elapsedTime;
				}
				
				this.totalRequests++;
				if(successful)
					this.successfulRequests++;
				else
					this.errorRequests++;
			}
		}
	}
	
	public long getStartTime() {
		return this.startTime;
	}
	
	public long getEndTime() {
		return this.endTime;
	}
	
	public long getTotalRequests() {
		return this.totalRequests;
	}
	
	public long getSuccessfulRequests() {
		return this.successfulRequests;
	}
	
	public long getErrorRequests() {
		return this.errorRequests;
	}	
}
